# Copyright (c) 2013, 2014 Dave Love, Liverpool University
# The licence for this file is as for the package itself.

# for make; must be common with oases
%global params CATEGORIES=64 MAXKMERLENGTH=500 OPENMP=1 BIGASSEMBLY=1 LONGSEQUENCES=1

Name:		velvet
Version:	1.2.10
Release:	3%{?dist}
Summary:	Nucleic acid sequence assembler for very short reads

# Main is GPL2+, some in contrib are GPL3+
License:	GPLv2+ and GPLv3+
URL:		http://www.ebi.ac.uk/~zerbino/velvet/
Source0:	http://www.ebi.ac.uk/~zerbino/velvet/velvet_%version.tgz
Patch1:		velvet-perl.patch
Patch2:		velvet-zlibh.patch
Patch3:		velvet-shebang.patch

BuildRequires:	zlib-devel, help2man, dos2unix
BuildRoot:	%{_tmppath}/hwloc-%version-%{release}-root-%(%{__id_u} -n)

%description
Velvet is a de novo genomic assembler specially designed for short read
sequencing technologies, such as Solexa or 454, developed by Daniel Zerbino and
Ewan Birney at the European Bioinformatics Institute (EMBL-EBI), near
Cambridge, in the United Kingdom.

Velvet currently takes in short read sequences, removes errors then produces
high quality unique contigs. It then uses paired read information, if
available, to retrieve the repeated areas between contigs.

Reference: Velvet: algorithms for de novo short read assembly using de
Bruijn graphs. D.R. Zerbino and E. Birney. Genome Research 18:821-829.


%package example
Summary:	Example data for %{name}
Requires:	%{name} = %{version}-%{release}

%description example
Example data for %{name}

%package devel
Summary:	Library of %{name} objects for building oases

%description devel
Library of %{name} objects (probably only for building oases)


%prep
%setup -q -n %{name}_%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
rm -r third-party/zlib-1.2.3
rm contrib/MetaVelvet-1.2.01/ISGraph/ISGraph.o \
   contrib/MetaVelvet-1.2.01/ISGraph/libISGraph.a \
   contrib/MetaVelvet-1.2.01/.hg_archival.txt
rm -r contrib/solaris contrib/MetaVelvet-v0.3.1
# yes, it has doubled ^M
dos2unix contrib/show_repeats/show_repeats.pl
dos2unix contrib/show_repeats/show_repeats.pl


%build
make %{?_smp_mflags} %params CFLAGS="%{optflags}"
help2man --no-info --name="simple hashing program" ./velveth > velveth.1
help2man --no-info --name="de Bruijn graph construction, error removal and repeat resolution" -v " " ./velvetg > velvetg.1
make -C contrib/MetaVelvet-1.2.01 CFLAGS="%{optflags}"
pushd contrib/shuffleSequences_fasta
cc %{optflags} shuffleSeqs-fast.c -lz
rm *.[ch]
popd
rm -r contrib/MetaVelvet-1.2.01/[A-Z]* # leaves the executable
( cd obj
  ar r ../libvelvet.a allocArray.o autoOpen.o binarySequences.o concatenatedGraph.o dfib.o dfibHeap.o fib.o fibHeap.o graph.o graphStats.o kmer.o passageMarker.o readCoherentGraph.o readSet.o recycleBin.o tightString.o utility.o
)


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%_bindir $RPM_BUILD_ROOT%_datadir/%name \
         $RPM_BUILD_ROOT%_mandir/man1 $RPM_BUILD_ROOT%_libdir/%name \
	 $RPM_BUILD_ROOT%_includedir/velvet
install velvet[gh] $RPM_BUILD_ROOT%_bindir
cp -r data $RPM_BUILD_ROOT%_datadir/%name
cp -r contrib $RPM_BUILD_ROOT%_libdir/%name
install -m 644 velvet*.1 $RPM_BUILD_ROOT%_mandir/man1
install -m 644 libvelvet.a $RPM_BUILD_ROOT%_libdir
pushd src
install -m 644 binarySequences.h concatenatedGraph.h dfibHeap.h fibHeap.h globals.h graph.h graphReConstruction.h graphStats.h kmer.h locallyCorrectedGraph.h passageMarker.h readSet.h recycleBin.h tightString.h utility.h $RPM_BUILD_ROOT%_includedir/velvet
popd


%clean
rm -rf $RPM_BUILD_ROOT

%check
cd tests
./run-tests.sh


%files
%defattr(-,root,root,-)
%doc LICENSE.txt CREDITS.txt *.pdf README.txt
%_bindir/*
%_mandir/man1/*
%_libdir/%name/contrib

%files example
%defattr(-,root,root,-)
%_datadir/%name/data

%files devel
%defattr(-,root,root,-)
%_libdir/libvelvet.a
%_includedir/velvet

%changelog
* Fri Jun  6 2014 Dave Love <d.love@liverpool.ac.uk> - 1.2.10-3
- Add test
- Patch to avoid bundled zlib.h
- Remove binaries in contrib
- Build metavelvet and move contrib to _libdir
- Pass CFLAGS to make

* Tue Jan 28 2014 Dave Love <d.love@liverpool.ac.uk> - 1.2.10-2
- Make devel package for oases

* Thu Jan 16 2014 Dave Love <d.love@liverpool.ac.uk> - 1.2.10-1
- Initial packaging
